@@ -20,7 +20,7 @@
  */
 /*
   File   : canonmn.cpp
-  Version: $Rev: 1366 $
+  Version: $Rev: 1473 $
   Authors: Andreas Huggel (ahu) <ahuggel@gmx.net>
            David Cannings (dc) <david@edeca.net>
   Credits: EXIF MakerNote of Canon by David Burren <http://www.burren.cx/david/canon.html>
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: canonmn.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: canonmn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -69,13 +69,6 @@ namespace Exiv2 {
             canonCfIfdId, MakerNote::AutoPtr(new CanonMakerNote));
         MakerNoteFactory::registerMakerNote(
             canonPiIfdId, MakerNote::AutoPtr(new CanonMakerNote));
-
-        ExifTags::registerMakerTagInfo(canonIfdId, tagInfo_);
-        ExifTags::registerMakerTagInfo(canonCsIfdId, tagInfoCs_);
-        ExifTags::registerMakerTagInfo(canonSiIfdId, tagInfoSi_);
-        ExifTags::registerMakerTagInfo(canonPaIfdId, tagInfoPa_);
-        ExifTags::registerMakerTagInfo(canonCfIfdId, tagInfoCf_);
-        ExifTags::registerMakerTagInfo(canonPiIfdId, tagInfoPi_);
     }
     //! @endcond
 
