@@ -21,7 +21,7 @@
 /*!
   @file    image.hpp
   @brief   Class JpegImage to access JPEG images
-  @version $Rev: 1366 $
+  @version $Rev: 1404 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @author  Brad Schick (brad)
@@ -295,6 +295,14 @@ namespace Exiv2 {
           specific MIME type may exist (e.g., "image/x-nikon-nef").
          */
         virtual std::string mimeType() const =0;
+        /*!
+          @brief Return the pixel width of the image.
+         */
+        virtual int pixelWidth() const { return pixelWidth_; }
+        /*!
+          @brief Return the pixel height of the image.
+         */
+        virtual int pixelHeight() const { return pixelHeight_; }
         /*!
           @brief Returns an ExifData instance containing currently buffered
               Exif data.
@@ -378,6 +386,8 @@ namespace Exiv2 {
         XmpData           xmpData_;           //!< XMP data container
         std::string       comment_;           //!< User comment
         std::string       xmpPacket_;         //!< XMP packet
+        int               pixelWidth_;        //!< image pixel width
+        int               pixelHeight_;       //!< image pixel height
 
     private:
         //! @name NOT implemented
