@@ -20,7 +20,7 @@
  */
 /*
   File:      jpgimage.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1404 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
              Brad Schick (brad) <brad@robotbattle.com>
   History:   15-Jan-05, brad: split out from image.cpp
@@ -28,7 +28,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: jpgimage.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: jpgimage.cpp 1404 2008-04-15 03:46:01Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -57,6 +57,28 @@ namespace Exiv2 {
     const byte     JpegBase::app1_     = 0xe1;
     const byte     JpegBase::app13_    = 0xed;
     const byte     JpegBase::com_      = 0xfe;
+
+// Start of Frame markers, nondifferential Huffman-coding frames
+    const byte     JpegBase::sof0_     = 0xc0;        // start of frame 0, baseline DCT
+    const byte     JpegBase::sof1_     = 0xc1;        // start of frame 1, extended sequential DCT, Huffman coding
+    const byte     JpegBase::sof2_     = 0xc2;        // start of frame 2, progressive DCT, Huffman coding
+    const byte     JpegBase::sof3_     = 0xc3;        // start of frame 3, lossless sequential, Huffman coding
+
+// Start of Frame markers, differential Huffman-coding frames
+    const byte     JpegBase::sof5_     = 0xc5;        // start of frame 5, differential sequential DCT, Huffman coding
+    const byte     JpegBase::sof6_     = 0xc6;        // start of frame 6, differential progressive DCT, Huffman coding
+    const byte     JpegBase::sof7_     = 0xc7;        // start of frame 7, differential lossless, Huffman coding
+
+// Start of Frame markers, nondifferential arithmetic-coding frames
+    const byte     JpegBase::sof9_     = 0xc9;        // start of frame 9, extended sequential DCT, arithmetic coding
+    const byte     JpegBase::sof10_    = 0xca;        // start of frame 10, progressive DCT, arithmetic coding
+    const byte     JpegBase::sof11_    = 0xcb;        // start of frame 11, lossless sequential, arithmetic coding
+
+// Start of Frame markers, differential arithmetic-coding frames
+    const byte     JpegBase::sof13_    = 0xcd;        // start of frame 13, differential sequential DCT, arithmetic coding
+    const byte     JpegBase::sof14_    = 0xce;        // start of frame 14, progressive DCT, arithmetic coding
+    const byte     JpegBase::sof15_    = 0xcf;        // start of frame 15, differential lossless, arithmetic coding
+
     const char     JpegBase::exifId_[] = "Exif\0\0";
     const char     JpegBase::jfifId_[] = "JFIF\0";
     const char     JpegBase::xmpId_[]  = "http://ns.adobe.com/xap/1.0/\0";
@@ -255,7 +277,7 @@ namespace Exiv2 {
             throw Error(15);
         }
         clearMetadata();
-        int search = 4;
+        int search = 5;
         const long bufMinSize = 36;
         long bufRead = 0;
         DataBuf buf(bufMinSize);
@@ -377,6 +399,18 @@ namespace Exiv2 {
                 }
                 --search;
             }
+            else if (   pixelHeight_ == 0
+                     && (   marker == sof0_  || marker == sof1_  || marker == sof2_
+                         || marker == sof3_  || marker == sof5_  || marker == sof6_ 
+                         || marker == sof7_  || marker == sof9_  || marker == sof10_
+                         || marker == sof11_ || marker == sof13_ || marker == sof14_
+                         || marker == sof15_)) {
+                // we hit a SOFn (start-of-frame) marker
+                if (size < 8) throw Error(15);
+                pixelHeight_ = getUShort(buf.pData_ + 3, bigEndian);
+                pixelWidth_ = getUShort(buf.pData_ + 5, bigEndian);
+                if (pixelHeight_ != 0) --search;
+            }
             else {
                 if (size < 2) {
                     rc = 4;
@@ -746,12 +780,7 @@ namespace Exiv2 {
     Image::AutoPtr newExvInstance(BasicIo::AutoPtr io, bool create)
     {
         Image::AutoPtr image;
-        if (create) {
-            image = Image::AutoPtr(new ExvImage(io, true));
-        }
-        else {
-            image = Image::AutoPtr(new ExvImage(io, false));
-        }
+        image = Image::AutoPtr(new ExvImage(io, create));
         if (!image->good()) image.reset();
         return image;
     }
@@ -767,7 +796,7 @@ namespace Exiv2 {
             || memcmp(tmpBuf + 2, ExvImage::exiv2Id_, 5) != 0) {
             result = false;
         }
-        if (!advance || !result ) iIo.seek(-7, BasicIo::cur);
+        if (!advance || !result) iIo.seek(-7, BasicIo::cur);
         return result;
     }
 
