@@ -20,7 +20,7 @@
  */
 /*
   File:      minoltamn.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1473 $
   Author(s): Gilles Caulier (cgilles) <caulier dot gilles at gmail dot com>
              Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   06-May-06, gc: submitted
@@ -29,7 +29,7 @@
 
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: minoltamn.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: minoltamn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -1230,12 +1230,6 @@ namespace Exiv2 {
         MakerNoteFactory::registerMakerNote(minoltaCs7DIfdId,  MakerNote::AutoPtr(new MinoltaMakerNote));
         MakerNoteFactory::registerMakerNote(minoltaCsOldIfdId, MakerNote::AutoPtr(new MinoltaMakerNote));
         MakerNoteFactory::registerMakerNote(minoltaCsNewIfdId, MakerNote::AutoPtr(new MinoltaMakerNote));
-
-        ExifTags::registerMakerTagInfo(minoltaIfdId,      tagInfo_);
-        ExifTags::registerMakerTagInfo(minoltaCs5DIfdId,  tagInfoCs5D_);
-        ExifTags::registerMakerTagInfo(minoltaCs7DIfdId,  tagInfoCs7D_);
-        ExifTags::registerMakerTagInfo(minoltaCsOldIfdId, tagInfoCsStd_);
-        ExifTags::registerMakerTagInfo(minoltaCsNewIfdId, tagInfoCsStd_);
     }
     //! @endcond
 
