@@ -20,7 +20,7 @@
  */
 /*
   File:      pentaxmn.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1473 $
   Author(s): Michal Cihar <michal@cihar.com>
   Based on fujimn.cpp by:
              Andreas Huggel (ahu) <ahuggel@gmx.net>
@@ -30,7 +30,7 @@
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: pentaxmn.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: pentaxmn.cpp 1473 2008-06-03 02:15:04Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -57,8 +57,6 @@ namespace Exiv2 {
         MakerNoteFactory::registerMakerNote("PENTAX*", "*", createPentaxMakerNote);
         MakerNoteFactory::registerMakerNote(
             pentaxIfdId, MakerNote::AutoPtr(new PentaxMakerNote));
-
-        ExifTags::registerMakerTagInfo(pentaxIfdId, tagInfo_);
     }
     //! @endcond
 
@@ -128,7 +126,17 @@ namespace Exiv2 {
         {    0x12ca0, N_("Optio A30") },
         {    0x12cb4, N_("Optio E40") },
         {    0x12cbe, N_("Optio M40") },
+        {    0x12cc8, N_("Optio Z10") },
         {    0x12cdc, N_("Optio S10") },
+        {    0x12ce6, N_("Optio A40") },
+        {    0x12cf0, N_("Optio V10") },
+        {    0x12cd2, N_("K20D") },
+        {    0x12cdc, N_("Optio S10") },
+        {    0x12ce6, N_("Optio A40") },
+        {    0x12cf0, N_("Optio V10") },
+        {    0x12cfa, N_("K200D") },
+        {    0x12d0e, N_("Optio E50") },
+        {    0x12d18, N_("Optio M50") },
     };
 
     //! Quality, tag 0x0008
@@ -138,6 +146,7 @@ namespace Exiv2 {
         {   2, N_("Best") },
         {   3, N_("TIFF") },
         {   4, N_("RAW") },
+        {   5, N_("Premium") },
     };
 
     //! Size, tag 0x0009
@@ -408,6 +417,7 @@ namespace Exiv2 {
     //! PictureMode, combi-tag 0x0033 (3 bytes)
     extern const TagDetails pentaxPictureMode[] = {
         { 0x000000, N_("Program") },
+        { 0x000300, N_("MTF Program") },
         { 0x000400, N_("Standard") },
         { 0x000500, N_("Portrait") },
         { 0x000600, N_("Landscape") },
@@ -468,9 +478,12 @@ namespace Exiv2 {
     extern const TagDetails pentaxDriveMode[] = {
         { 0x00000000, N_("Single-frame") },
         { 0x01000000, N_("Continuous") },
+        { 0x02000000, N_("Continuous (Hi)") },
+        { 0x03000000, N_("Burst") },
         { 0x00010000, N_("Self-timer (12 sec)") },
         { 0x00020000, N_("Self-timer (2 sec)") },
-        { 0x00000100, N_("Remote Control?") },
+        { 0x00000100, N_("Remote Control (3 sec)") },
+        { 0x00000200, N_("Remote Control") },
         { 0x00000001, N_("Multiple Exposure") },
     };
 
@@ -596,10 +609,19 @@ namespace Exiv2 {
         { 0x060d, "smc PENTAX-FA* 400mm F5.6 ED[IF]" },
         { 0x060e, "smc PENTAX-FA* MACRO 200mm F4 ED[IF]" },
         { 0x0700, "smc PENTAX-DA 21mm F3.2 AL Limited" },
+        { 0x07e5, "smc PENTAX-DA 18-55mm F3.5-5.6 AL II" },
+        { 0x07e6, "Tamron AF 17-50mm F2.8 XR Di-II LD (Model A16)" },
         { 0x07e7, "smc PENTAX-DA 18-250mm F3.5-6.3ED AL [IF]" },
+        { 0x07e9, "smc PENTAX-DA 35mm F2.8 Macro Limited" },
+        { 0x07ea, "smc PENTAX-DA* 300 mm F4ED [IF] SDM (SDM not used)" },
+        { 0x07eb, "smc PENTAX-DA* 200mm F2.8 ED [IF] SDM (SDM not used)" },
         { 0x07ee, "TAMRON AF 18-250mm F3.5-6.3 Di II LD Aspherical [IF] MACRO" },
+        { 0x07f1, "smc PENTAX-DA* 50-135mm F2.8 ED [IF] SDM (SDM not used)" },
+        { 0x07f2, "smc PENTAX-DA* 16-50mm F2.8 ED AL [IF] SDM (SDM not used)" },
         { 0x07f3, "smc PENTAX-DA 70mm F2.4 Limited" },
         { 0x07f4, "smc PENTAX-DA 21mm F3.2 AL Limited" },
+        { 0x08ea, "smc PENTAX-DA* 300 mm F4ED [IF] SDM" },
+        { 0x08eb, "smc PENTAX-DA* 200mm F2.8 ED [IF] SDM" },
         { 0x08f1, "smc PENTAX-DA* 50-135mm F2.8 ED [IF] SDM" },
         { 0x08f2, "smc PENTAX-DA* 16-50mm F2.8 ED AL [IF] SDM" },
     };
@@ -608,6 +630,24 @@ namespace Exiv2 {
     extern const TagDetails pentaxImageTone[] = {
         {    0, N_("Natural") },
         {    1, N_("Bright") },
+        {    2, N_("Portrait") },
+        {    3, N_("Landscape") },
+        {    4, N_("Vibrant") },
+        {    5, N_("Monochrome") },
+    };
+    
+    //! DynamicRangeExpansion, tag 0x0069
+    extern const TagDetails pentaxDynamicRangeExpansion[] = {
+        {   0, N_("Off") },
+        {   0x1000000, N_("On") },
+    };
+
+    //! HighISONoiseReduction, tag 0x0071
+    extern const TagDetails pentaxHighISONoiseReduction[] = {
+        {   0, N_("Off") },
+        {   1, N_("Weakest") },
+        {   2, N_("Weak") },
+        {   3, N_("Strong") },
     };
 
     std::ostream& PentaxMakerNote::printPentaxVersion(std::ostream& os, const Value& value)
@@ -845,11 +885,20 @@ namespace Exiv2 {
         TagInfo(0x0026, "DestinationDST", N_("Destination DST"),
                 N_("Whether day saving time is active in destination"),
                 pentaxIfdId, makerTags, undefined, EXV_PRINT_TAG(pentaxYesNo)),
-        /* Some missing ! */
+        TagInfo(0x0027, "DSPFirmwareVersion", N_("DSPFirmwareVersion"),
+                N_("DSPFirmwareVersion"),
+                pentaxIfdId, makerTags, unsignedByte, printValue), /* TODO: Decoding missing */
+        TagInfo(0x0028, "CPUFirmwareVersion", N_("CPUFirmwareVersion"),
+                N_("CPUFirmwareVersion"),
+                pentaxIfdId, makerTags, unsignedByte, printValue), /* TODO: Decoding missing */
         TagInfo(0x0029, "FrameNumber", N_("Frame number"),
                 N_("Frame number"),
                 pentaxIfdId, makerTags, undefined, printValue),
         /* Some missing ! */
+        TagInfo(0x002d, "EffectiveLV", N_("Light value"),
+                N_("Camera calculated light value, includes exposure compensation"),
+                pentaxIfdId, makerTags, unsignedShort, printValue),
+        /* Some missing ! */
         TagInfo(0x0032, "ImageProcessing", N_("Image processing"),
                 N_("Image processing"),
                 pentaxIfdId, makerTags, undefined, EXV_PRINT_COMBITAG(pentaxImageProcessing, 4, 0)),
@@ -864,10 +913,15 @@ namespace Exiv2 {
                 N_("Color space"),
                 pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxColorSpace)),
         /* Some missing ! */
+        TagInfo(0x003e, "PreviewImageBorders", N_("Preview image borders"),
+                N_("Preview image borders"),
+                pentaxIfdId, makerTags, unsignedByte, printValue),
         TagInfo(0x003f, "LensType", N_("Lens type"),
                 N_("Lens type"),
                 pentaxIfdId, makerTags, unsignedByte, EXV_PRINT_COMBITAG(pentaxLensType, 2, 1)),
-        /* Some missing ! */
+        TagInfo(0x0040, "SensitivityAdjust", N_("Sensitivity adjust"),
+                N_("Sensitivity adjust"),
+                pentaxIfdId, makerTags, unsignedLong, printValue),
         TagInfo(0x0041, "DigitalFilter", N_("Digital filter"),
                 N_("Digital filter"),
                 pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxOffOn)),
@@ -875,7 +929,9 @@ namespace Exiv2 {
         TagInfo(0x0047, "Temperature", N_("Temperature"),
                 N_("Camera temperature"),
                 pentaxIfdId, makerTags, signedByte, printPentaxTemperature),
-        /* Some missing ! */
+        TagInfo(0x0048, "AELock", N_("AE lock"),
+                N_("AE lock"),
+                pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxOffOn)),
         TagInfo(0x0049, "NoiseReduction", N_("Noise reduction"),
                 N_("Noise reduction"),
                 pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxOffOn)),
@@ -887,6 +943,9 @@ namespace Exiv2 {
         TagInfo(0x004f, "ImageTone", N_("Image tone"),
                 N_("Image tone"),
                 pentaxIfdId, makerTags, unsignedShort, EXV_PRINT_TAG(pentaxImageTone)),
+        TagInfo(0x0050, "ColorTemperature", N_("Colort temperature"),
+                N_("Colort temperature"),
+                pentaxIfdId, makerTags, unsignedShort, printValue),
         /* Some missing ! */
         TagInfo(0x005c, "ShakeReduction", N_("Shake reduction"),
                 N_("Shake reduction information"),
@@ -894,6 +953,12 @@ namespace Exiv2 {
         TagInfo(0x005d, "ShutterCount", N_("Shutter count"),
                 N_("Shutter count"),
                 pentaxIfdId, makerTags, undefined, printValue), /* TODO: This has some encryption by date (see exiftool) */
+        TagInfo(0x0069, "DynamicRangeExpansion", N_("Dynamic range expansion"),
+                N_("Dynamic range expansion"),
+                pentaxIfdId, makerTags, undefined, EXV_PRINT_COMBITAG(pentaxDynamicRangeExpansion, 4, 0)),
+        TagInfo(0x0071, "HighISONoiseReduction", N_("High ISO noise reduction"),
+                N_("High ISO noise reduction"),
+                pentaxIfdId, makerTags, unsignedByte, EXV_PRINT_TAG(pentaxHighISONoiseReduction)),
         /* Many missing ! */
         TagInfo(0x0200, "BlackPoint", N_("Black point"),
                 N_("Black point"),
@@ -902,6 +967,9 @@ namespace Exiv2 {
                 N_("White point"),
                 pentaxIfdId, makerTags, undefined, printValue),
         /* Some missing ! */
+        TagInfo(0x0205, "ShotInfo", N_("ShotInfo"),
+                N_("ShotInfo"),
+                pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
         TagInfo(0x0206, "AEInfo", N_("AEInfo"),
                 N_("AEInfo"),
                 pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
@@ -954,8 +1022,8 @@ namespace Exiv2 {
         TagInfo(0x021f, "AFInfo", N_("AFInfo"),
                 N_("AFInfo"),
                 pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
-        TagInfo(0x0206, "Saturation", N_("Saturation"),
-                N_("Saturation"),
+        TagInfo(0x0222, "ColorInfo", N_("ColorInfo"),
+                N_("ColorInfo"),
                 pentaxIfdId, makerTags, undefined, printValue), /* TODO: Decoding missing */
         // End of list marker
         TagInfo(0xffff, "(UnknownPentaxMakerNoteTag)", "(UnknownPentaxMakerNoteTag)",
