@@ -20,14 +20,14 @@
  */
 /*
   File:      rafimage.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1404 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   05-Feb-07, ahu: created
   Credits:   See header file
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: rafimage.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: rafimage.cpp 1404 2008-04-15 03:46:01Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -59,6 +59,18 @@ namespace Exiv2 {
     {
     } // RafImage::RafImage
 
+    int RafImage::pixelWidth() const
+    {
+        Exiv2::ExifData::const_iterator widthIter = exifData_.findKey(Exiv2::ExifKey("Exif.Photo.PixelXDimension"));
+        return (widthIter == exifData_.end()) ? 0 : widthIter->toLong();
+    }
+
+    int RafImage::pixelHeight() const
+    {
+        Exiv2::ExifData::const_iterator heightIter = exifData_.findKey(Exiv2::ExifKey("Exif.Photo.PixelYDimension"));
+        return (heightIter == exifData_.end()) ? 0 : heightIter->toLong();
+    }
+
     void RafImage::setExifData(const ExifData& /*exifData*/)
     {
         // Todo: implement me!
