@@ -21,7 +21,7 @@
 /*!
   @file    rafimage.hpp
   @brief   Fujifilm RAW image
-  @version $Rev: 1366 $
+  @version $Rev: 1404 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    05-Feb-07, ahu: created
@@ -103,6 +103,8 @@ namespace Exiv2 {
         //! @name Accessors
         //@{
         std::string mimeType() const { return "image/x-fuji-raf"; }
+        int pixelWidth() const;
+        int pixelHeight() const;
         //@}
 
     private:
