@@ -20,14 +20,14 @@
  */
 /*
   File:      tiffparser.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1402 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   15-Mar-06, ahu: created
 
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: tiffparser.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: tiffparser.cpp 1402 2008-04-04 15:50:11Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -148,9 +148,9 @@ namespace Exiv2 {
         { "*",         0x8649, Group::ifd0,    &TiffMetadataDecoder::decodeIptc         }
     };
 
-    const DecoderFct TiffDecoder::findDecoder(const std::string& make,
-                                                    uint32_t     extendedTag,
-                                                    uint16_t     group)
+    DecoderFct TiffDecoder::findDecoder(const std::string& make,
+                                              uint32_t     extendedTag,
+                                              uint16_t     group)
     {
         DecoderFct decoderFct = &TiffMetadataDecoder::decodeStdTiffEntry;
         const TiffDecoderInfo* td = find(tiffDecoderInfo_,
