@@ -21,7 +21,7 @@
 /*!
   @file    value.hpp
   @brief   Value interface and concrete subclasses
-  @version $Rev: 1366 $
+  @version $Rev: 1421 $
   @author  Andreas Huggel (ahu)
            <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
   @date    09-Jan-04, ahu: created
@@ -485,6 +485,7 @@ namespace Exiv2 {
 
         //! @name Manipulators
         //@{
+        using StringValueBase::read;
         /*!
           @brief Set the value to that of the string buf. Overrides base class
                  to append a terminating '\\0' character if buf doesn't end
@@ -572,6 +573,7 @@ namespace Exiv2 {
 
         //! @name Manipulators
         //@{
+        using StringValueBase::read;
         /*!
           @brief Read the value from a comment
 
@@ -716,6 +718,7 @@ namespace Exiv2 {
 
         //! @name Manipulators
         //@{
+        using XmpValue::read;
         /*!
           @brief Read a simple property value from \em buf to set the value.
 
@@ -795,6 +798,7 @@ namespace Exiv2 {
 
         //! @name Manipulators
         //@{
+        using XmpValue::read;
         /*!
           @brief Read a simple property value from \em buf and append it 
                  to the value.
@@ -863,6 +867,7 @@ namespace Exiv2 {
 
         //! @name Manipulators
         //@{
+        using XmpValue::read;
         /*!
           @brief Read a simple property value from \em buf and append it 
                  to the value.
@@ -888,11 +893,19 @@ namespace Exiv2 {
         AutoPtr clone() const;
         virtual long count() const;
         /*!
-          @brief Return the <EM>n</EM>-th component of the value as a string.
-                 The behaviour of this method may be undefined if there is no
-                 <EM>n</EM>-th component.
+          @brief Return the text value associated with the default language
+                 qualifier \c x-default. The parameter \em n is not used, but
+                 it is suggested that only 0 is passed in. Returns an empty
+                 string and sets the ok-flag to \c false if there is no
+                 default value.
          */
         virtual std::string toString(long n) const;
+        /*!
+          @brief Return the text value associated with the language qualifier
+                 \em qualifier. Returns an empty string and sets the ok-flag
+                 to \c false if there is no entry for the language qualifier.
+         */
+        std::string toString(const std::string& qualifier) const;
         virtual long toLong(long n =0) const;
         virtual float toFloat(long n =0) const;
         virtual Rational toRational(long n =0) const;
