@@ -20,13 +20,13 @@
  */
 /*
   File:      xmp.cpp
-  Version:   $Rev: 1366 $
+  Version:   $Rev: 1484 $
   Author(s): Andreas Huggel (ahu) <ahuggel@gmx.net>
   History:   13-July-07, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Id: xmp.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
+EXIV2_RCSID("@(#) $Id: xmp.cpp 1484 2008-06-04 08:38:14Z ahuggel $")
 
 // *****************************************************************************
 // included header files
@@ -45,11 +45,12 @@ EXIV2_RCSID("@(#) $Id: xmp.cpp 1366 2008-01-09 16:44:09Z ahuggel $")
 // Adobe XMP Toolkit
 #ifdef EXV_HAVE_XMP_TOOLKIT
 # define TXMP_STRING_TYPE std::string
-# include <XMP.hpp>
+# include <XMPSDK.hpp>
 # include <XMP.incl_cpp>
 #endif // EXV_HAVE_XMP_TOOLKIT
 
 // *****************************************************************************
+// local declarations
 namespace {
     //! Unary predicate that matches an Xmpdatum by key
     class FindXmpdatum {
@@ -74,7 +75,7 @@ namespace {
     Exiv2::XmpValue::XmpStruct xmpStruct(const XMP_OptionBits& opt);
 
     //! Convert Value::XmpStruct to XMP Toolkit array option bits
-    XMP_OptionBits xmpOptionBits(Exiv2::XmpValue::XmpStruct xs);
+    XMP_OptionBits xmpArrayOptionBits(Exiv2::XmpValue::XmpStruct xs);
 
     //! Convert XMP Toolkit array option bits to array TypeId
     Exiv2::TypeId arrayValueTypeId(const XMP_OptionBits& opt);
@@ -83,7 +84,10 @@ namespace {
     Exiv2::XmpValue::XmpArrayType xmpArrayType(const XMP_OptionBits& opt);
 
     //! Convert Value::XmpArrayType to XMP Toolkit array option bits
-    XMP_OptionBits xmpOptionBits(Exiv2::XmpValue::XmpArrayType xat);
+    XMP_OptionBits xmpArrayOptionBits(Exiv2::XmpValue::XmpArrayType xat);
+
+    //! Convert XmpFormatFlags to XMP Toolkit format option bits
+    XMP_OptionBits xmpFormatOptionBits(Exiv2::XmpParser::XmpFormatFlags flags);
 
 # ifdef DEBUG
     //! Print information about a parsed XMP node
@@ -246,6 +250,11 @@ namespace Exiv2 {
         return 0;
     }
 
+    std::ostream& Xmpdatum::write(std::ostream& os) const
+    {
+        return XmpProperties::printProperty(os, key(), value());
+    }
+
     Xmpdatum& Xmpdatum::operator=(const std::string& value)
     {
         setValue(value);
@@ -287,7 +296,7 @@ namespace Exiv2 {
         return *pos;
     }
 
-    int XmpData::add(const XmpKey& key, Value* value)
+    int XmpData::add(const XmpKey& key, const Value* value)
     {
         return add(Xmpdatum(key, value));
     }
@@ -371,6 +380,7 @@ namespace Exiv2 {
 
     void XmpParser::terminate()
     {
+        XmpProperties::unregisterNs();
         if (initialized_) {
 #ifdef EXV_HAVE_XMP_TOOLKIT
             SXMPMeta::Terminate();
@@ -379,10 +389,10 @@ namespace Exiv2 {
         }
     }
 
+#ifdef EXV_HAVE_XMP_TOOLKIT
     bool XmpParser::registerNs(const std::string& ns, 
                                const std::string& prefix)
     {
-#ifdef EXV_HAVE_XMP_TOOLKIT
         try {
             initialize();
             return SXMPMeta::RegisterNamespace(ns.c_str(), prefix.c_str(), 0);
@@ -390,11 +400,28 @@ namespace Exiv2 {
         catch (const XMP_Error& e) {
             throw Error(40, e.GetID(), e.GetErrMsg());
         }
+    } // XmpParser::registerNs
 #else
+    bool XmpParser::registerNs(const std::string& /*ns*/, 
+                               const std::string& /*prefix*/)
+    {
         initialize();
         return true;
+    } // XmpParser::registerNs
 #endif
-	} // XmpParser::registerNs
+
+    void XmpParser::unregisterNs(const std::string& /*ns*/)
+    {
+#ifdef EXV_HAVE_XMP_TOOLKIT
+        try {
+// Throws XMP Toolkit error 8: Unimplemented method XMPMeta::DeleteNamespace
+//          SXMPMeta::DeleteNamespace(ns.c_str());
+        }
+        catch (const XMP_Error& e) {
+            throw Error(40, e.GetID(), e.GetErrMsg());
+        }
+#endif
+    } // XmpParser::unregisterNs
 
 #ifdef EXV_HAVE_XMP_TOOLKIT
     int XmpParser::decode(      XmpData&     xmpData,
@@ -545,7 +572,9 @@ namespace Exiv2 {
 
 #ifdef EXV_HAVE_XMP_TOOLKIT
     int XmpParser::encode(      std::string& xmpPacket,
-                          const XmpData&     xmpData)
+                          const XmpData&     xmpData,
+                                uint16_t     formatFlags,
+                                uint32_t     padding)
     { try {
         if (xmpData.empty()) return 0;
 
@@ -590,8 +619,8 @@ namespace Exiv2 {
             // Todo: Xmpdatum should have an XmpValue, not a Value
             const XmpValue* val = dynamic_cast<const XmpValue*>(&i->value());
             assert(val);
-            options =   xmpOptionBits(val->xmpArrayType())
-                      | xmpOptionBits(val->xmpStruct());
+            options =   xmpArrayOptionBits(val->xmpArrayType())
+                      | xmpArrayOptionBits(val->xmpStruct());
             if (   i->typeId() == xmpBag
                 || i->typeId() == xmpSeq
                 || i->typeId() == xmpAlt) {
@@ -627,7 +656,7 @@ namespace Exiv2 {
             throw Error(38, i->tagName(), TypeInfo::typeName(i->typeId()));
         }
         std::string tmpPacket;
-        meta.SerializeToBuffer(&tmpPacket, kXMP_UseCompactFormat); // throws
+        meta.SerializeToBuffer(&tmpPacket, xmpFormatOptionBits(static_cast<XmpFormatFlags>(formatFlags)), padding); // throws
         xmpPacket = tmpPacket;
 
         return 0;
@@ -639,8 +668,10 @@ namespace Exiv2 {
         return 3;
     }} // XmpParser::decode
 #else
-    int XmpParser::encode(      std::string& xmpPacket,
-                          const XmpData&     xmpData)
+    int XmpParser::encode(      std::string& /*xmpPacket*/,
+                          const XmpData&     xmpData,
+                                uint16_t     /*formatFlags*/,
+                                uint32_t     /*padding*/)
     {
         if (!xmpData.empty()) {
 #ifndef SUPPRESS_WARNINGS
@@ -651,13 +682,6 @@ namespace Exiv2 {
     } // XmpParser::encode
 #endif // !EXV_HAVE_XMP_TOOLKIT
 
-    // *************************************************************************
-    // free functions
-    std::ostream& operator<<(std::ostream& os, const Xmpdatum& md)
-    {
-        return os << md.value();
-    }
-
 }                                       // namespace Exiv2
 
 // *****************************************************************************
@@ -674,7 +698,7 @@ namespace {
         return var;
     }
 
-    XMP_OptionBits xmpOptionBits(Exiv2::XmpValue::XmpStruct xs)
+    XMP_OptionBits xmpArrayOptionBits(Exiv2::XmpValue::XmpStruct xs)
     {
         XMP_OptionBits var(0);
         switch (xs) {
@@ -703,7 +727,7 @@ namespace {
         return Exiv2::XmpValue::xmpArrayType(arrayValueTypeId(opt));
     }
 
-    XMP_OptionBits xmpOptionBits(Exiv2::XmpValue::XmpArrayType xat)
+    XMP_OptionBits xmpArrayOptionBits(Exiv2::XmpValue::XmpArrayType xat)
     {
         XMP_OptionBits var(0);
         switch (xat) {
@@ -724,6 +748,19 @@ namespace {
         return var;
     }
 
+    XMP_OptionBits xmpFormatOptionBits(Exiv2::XmpParser::XmpFormatFlags flags)
+    {
+        XMP_OptionBits var(0);
+        if (flags & Exiv2::XmpParser::omitPacketWrapper)   var |= kXMP_OmitPacketWrapper;
+        if (flags & Exiv2::XmpParser::readOnlyPacket)      var |= kXMP_ReadOnlyPacket;
+        if (flags & Exiv2::XmpParser::useCompactFormat)    var |= kXMP_UseCompactFormat;
+        if (flags & Exiv2::XmpParser::includeThumbnailPad) var |= kXMP_IncludeThumbnailPad;
+        if (flags & Exiv2::XmpParser::exactPacketLength)   var |= kXMP_ExactPacketLength;
+        if (flags & Exiv2::XmpParser::writeAliasComments)  var |= kXMP_WriteAliasComments;
+        if (flags & Exiv2::XmpParser::omitAllFormatting)   var |= kXMP_OmitAllFormatting;
+        return var;
+    }
+
 #ifdef DEBUG
     void printNode(const std::string& schemaNs,
                    const std::string& propPath,
